Package: BarcodingR
Title: Species Identification using DNA Barcodes
Version: 1.0-3
Date: 2020-04-10
Authors@R: c(person("Ai-bing", "ZHANG",  role = c("aut", "cre"),email = "Zhangab2008@mail.cnu.edu.cn"),person("Meng-di", "HAO",  role = c("aut"),email = "dreamdy521@163.com"),person("Cai-qing", "YANG",  role = c("aut"),email = "279226090@qq.com"),person("Zhi-yong", "SHI",  role = c("aut"),email = "zhiyong-shi@163.com"))
Description: To perform species identification using DNA barcodes.
Depends: R (>= 3.2.1),ape,nnet,class,stats,sp
Suggests: cluster,compiler,utils
License: GPL-2
LazyData: true
ByteCompile: true
Encoding: UTF-8
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-04-14 13:47:36 UTC; Administrator
Author: Ai-bing ZHANG [aut, cre],
  Meng-di HAO [aut],
  Cai-qing YANG [aut],
  Zhi-yong SHI [aut]
Maintainer: Ai-bing ZHANG <Zhangab2008@mail.cnu.edu.cn>
Repository: CRAN
Date/Publication: 2020-04-14 15:00:05 UTC
Built: R 4.6.0; ; 2026-04-25 23:50:06 UTC; unix
