# Generated by roxygen2: do not edit by hand

export(DNAbin2kmerFreqMatrix)
export(FMF)
export(FMFtheta12)
export(NAMES)
export(TDR2)
export(barcodes.eval)
export(barcoding.gap)
export(barcoding.spe.identify)
export(barcoding.spe.identify2)
export(bbsik)
export(char2NumVector)
export(compare2delimitations)
export(consensus.identify)
export(digitize.DNA)
export(optimize.kmer)
export(sample.ref)
export(save.ids)
export(summarize.ref)
import(ape)
import(class)
import(graphics)
import(nnet)
import(sp)
import(stats)
import(utils)
